@@ -11,18 +11,19 @@ For more information, access: 'https://github.com/snakypy/snakypy-helpers'
 :copyright: Copyright 2020-2021 by Snakypy team, see AUTHORS.rst.
 :license: MIT license, see LICENSE for details.
 """
-
+from os.path import abspath, dirname, join
 
 import snakypy.helpers.ansi
 import snakypy.helpers.calcs
 import snakypy.helpers.catches
 import snakypy.helpers.console
+import snakypy.helpers.decorators
 import snakypy.helpers.files
 import snakypy.helpers.os
 import snakypy.helpers.path
-import snakypy.helpers.decorators
-from snakypy.helpers.ansi import BG, FG, SGR, NONE
+from snakypy.helpers.ansi import BG, FG, NONE, SGR
 from snakypy.helpers.console import entry, pick, printer
+from snakypy.helpers.files import eqversion
 
 __info__ = {
     "name": "Snakypy Organization",
@@ -30,5 +31,9 @@ __info__ = {
     "email": "contact.snakypy@gmail.com",
     "website": "https://snakypy.github.io",
     "github": "https://github.com/snakypy",
-    "version": "0.1.3",
+    "version": "0.2.0",
 }
+
+# Keep the versions the same on pyproject.toml and __init__.py
+pyproject = join(dirname(abspath(__file__)), "../..", "pyproject.toml")
+eqversion(pyproject, __info__["version"])
